linux-firmware.lore.kernel.org archive mirror
 help / color / mirror / Atom feed
From: Mario Limonciello <mario.limonciello@amd.com>
To: <linux-firmware@kernel.org>, Josh Boyer <jwboyer@kernel.org>
Cc: Mario Limonciello <mario.limonciello@amd.com>
Subject: [PATCH 15/20] carl9170fw: correct typographical errors caught by codespell
Date: Tue, 15 Aug 2023 13:00:13 -0500	[thread overview]
Message-ID: <20230815180018.25554-16-mario.limonciello@amd.com> (raw)
In-Reply-To: <20230815180018.25554-1-mario.limonciello@amd.com>

Signed-off-by: Mario Limonciello <mario.limonciello@amd.com>
---
 carl9170fw/carlfw/Kconfig                            |  2 +-
 carl9170fw/carlfw/carl9170.lds                       |  4 ++--
 carl9170fw/carlfw/include/dma.h                      |  2 +-
 carl9170fw/carlfw/src/wlan.c                         |  4 ++--
 carl9170fw/carlfw/src/wol.c                          |  2 +-
 carl9170fw/extra/FindGPERF.cmake                     |  2 +-
 carl9170fw/extra/FindPackageHandleStandardArgs.cmake |  8 ++++----
 carl9170fw/include/shared/fwcmd.h                    |  2 +-
 carl9170fw/include/shared/phy.h                      |  2 +-
 carl9170fw/tools/carlu/src/fw.c                      |  2 +-
 carl9170fw/tools/carlu/src/test.c                    |  4 ++--
 carl9170fw/tools/carlu/src/usb.c                     |  6 +++---
 carl9170fw/tools/include/frame.h                     | 12 ++++++------
 13 files changed, 26 insertions(+), 26 deletions(-)

diff --git a/carl9170fw/carlfw/Kconfig b/carl9170fw/carlfw/Kconfig
index f42268c4..bc268da3 100644
--- a/carl9170fw/carlfw/Kconfig
+++ b/carl9170fw/carlfw/Kconfig
@@ -155,7 +155,7 @@ config CARL9170FW_NOISY_MAC_RESET
 
 config CARL9170FW_BROKEN_FEATURES
 	def_bool n
-	prompt "Broken Featurs"
+	prompt "Broken Features"
 
 config CARL9170FW_DEBUG
 	def_bool n
diff --git a/carl9170fw/carlfw/carl9170.lds b/carl9170fw/carlfw/carl9170.lds
index 97dda684..9078de9c 100644
--- a/carl9170fw/carlfw/carl9170.lds
+++ b/carl9170fw/carlfw/carl9170.lds
@@ -1,7 +1,7 @@
 /*
- * The carl9170 firwmare gets copied into the device's
+ * The carl9170 firmware gets copied into the device's
  * Program RAM (pram), which has a size of 16K, but
- * also has to accomodate the stack the device uses,
+ * also has to accommodate the stack the device uses,
  * which starts at the top of the 16k, so we pretend
  * that we just have 16256 (16k - 128) of pram.
  *
diff --git a/carl9170fw/carlfw/include/dma.h b/carl9170fw/carlfw/include/dma.h
index 8f3a9df6..c7a50595 100644
--- a/carl9170fw/carlfw/include/dma.h
+++ b/carl9170fw/carlfw/include/dma.h
@@ -313,7 +313,7 @@ static inline __inline unsigned int queue_len(struct dma_queue *q)
 }
 
 /*
- * rearm a completed packet, so it will be processed agian.
+ * rearm a completed packet, so it will be processed again.
  */
 static inline __inline void dma_rearm(struct dma_desc *desc)
 {
diff --git a/carl9170fw/carlfw/src/wlan.c b/carl9170fw/carlfw/src/wlan.c
index d3328d67..87abbdbd 100644
--- a/carl9170fw/carlfw/src/wlan.c
+++ b/carl9170fw/carlfw/src/wlan.c
@@ -587,7 +587,7 @@ static void wlan_send_buffered_ba(void)
 	memset(ba->bitmap, 0x0, sizeof(ba->bitmap));
 
 	/*
-	 * Both, the original firmare and ath9k set the NO ACK flag in
+	 * Both, the original firmware and ath9k set the NO ACK flag in
 	 * the BA Ack Policy subfield.
 	 */
 	ba->control = ctx->control | cpu_to_le16(1);
@@ -711,7 +711,7 @@ static unsigned int wlan_rx_filter(struct dma_desc *desc)
 				/*
 				 * Don't filter block acks when the application
 				 * has queued BARs. This is because the firmware
-				 * can't do the accouting and the application
+				 * can't do the accounting and the application
 				 * has to sort out if the BA belongs to any BARs.
 				 */
 				break;
diff --git a/carl9170fw/carlfw/src/wol.c b/carl9170fw/carlfw/src/wol.c
index 7afb8e52..e8b025ff 100644
--- a/carl9170fw/carlfw/src/wol.c
+++ b/carl9170fw/carlfw/src/wol.c
@@ -46,7 +46,7 @@ void wol_prepare(void)
 	/* set filter policy to: discard everything */
 	fw.wlan.rx_filter = CARL9170_RX_FILTER_EVERYTHING;
 
-	/* reenable rx dma */
+	/* re-enable rx dma */
 	wlan_trigger(AR9170_DMA_TRIGGER_RXQ);
 
 	/* initialize the last_beacon timer */
diff --git a/carl9170fw/extra/FindGPERF.cmake b/carl9170fw/extra/FindGPERF.cmake
index baf87494..ee1cdfcf 100644
--- a/carl9170fw/extra/FindGPERF.cmake
+++ b/carl9170fw/extra/FindGPERF.cmake
@@ -22,7 +22,7 @@
 #  alias for GperfOutput
 #  GPERF_${Name}_INPUT - the gperf source file, an alias for ${GperfInput}
 #
-# Gperf scanners oftenly use tokens  defined by Bison: the code generated
+# Gperf scanners often use tokens  defined by Bison: the code generated
 # by Gperf  depends of the header  generated by Bison.   This module also
 # defines a macro:
 #  ADD_GPERF_BISON_DEPENDENCY(GperfTarget BisonTarget)
diff --git a/carl9170fw/extra/FindPackageHandleStandardArgs.cmake b/carl9170fw/extra/FindPackageHandleStandardArgs.cmake
index ec3440c0..a3c7b256 100644
--- a/carl9170fw/extra/FindPackageHandleStandardArgs.cmake
+++ b/carl9170fw/extra/FindPackageHandleStandardArgs.cmake
@@ -10,20 +10,20 @@
 # the name of the Find-module where it is called (in original casing).
 #
 # The first simple mode looks like this:
-#    FIND_PACKAGE_HANDLE_STANDARD_ARGS(<name> (DEFAULT_MSG|"Custom failure message") <var1>...<varN> )
-# If the variables <var1> to <varN> are all valid, then <UPPERCASED_NAME>_FOUND
+#    FIND_PACKAGE_HANDLE_STANDARD_ARGS(<name> (DEFAULT_MSG|"Custom failure message") <var1>...<warn> )
+# If the variables <var1> to <warn> are all valid, then <UPPERCASED_NAME>_FOUND
 # will be set to TRUE.
 # If DEFAULT_MSG is given as second argument, then the function will generate
 # itself useful success and error messages. You can also supply a custom error message
 # for the failure case. This is not recommended.
 #
 # The second mode is more powerful and also supports version checking:
-#    FIND_PACKAGE_HANDLE_STANDARD_ARGS(NAME [REQUIRED_VARS <var1>...<varN>]
+#    FIND_PACKAGE_HANDLE_STANDARD_ARGS(NAME [REQUIRED_VARS <var1>...<warn>]
 #                                           [VERSION_VAR   <versionvar>
 #                                           [CONFIG_MODE]
 #                                           [FAIL_MESSAGE "Custom failure message"] )
 #
-# As above, if <var1> through <varN> are all valid, <UPPERCASED_NAME>_FOUND
+# As above, if <var1> through <warn> are all valid, <UPPERCASED_NAME>_FOUND
 # will be set to TRUE.
 # After REQUIRED_VARS the variables which are required for this package are listed.
 # Following VERSION_VAR the name of the variable can be specified which holds
diff --git a/carl9170fw/include/shared/fwcmd.h b/carl9170fw/include/shared/fwcmd.h
index 9443c802..f4adca52 100644
--- a/carl9170fw/include/shared/fwcmd.h
+++ b/carl9170fw/include/shared/fwcmd.h
@@ -68,7 +68,7 @@ enum carl9170_cmd_oids {
 	CARL9170_CMD_FREQ_START		= 0x23,
 	CARL9170_CMD_PSM		= 0x24,
 
-	/* Asychronous command flag */
+	/* Asynchronous command flag */
 	CARL9170_CMD_ASYNC_FLAG		= 0x40,
 	CARL9170_CMD_WREG_ASYNC		= (CARL9170_CMD_WREG |
 					   CARL9170_CMD_ASYNC_FLAG),
diff --git a/carl9170fw/include/shared/phy.h b/carl9170fw/include/shared/phy.h
index 024fb42b..f05388d3 100644
--- a/carl9170fw/include/shared/phy.h
+++ b/carl9170fw/include/shared/phy.h
@@ -177,7 +177,7 @@
 #define	AR9170_PHY_REG_BIN_MASK_3		(AR9170_PHY_REG_BASE + 0x0108)
 #define	AR9170_PHY_REG_MASK_CTL			(AR9170_PHY_REG_BASE + 0x010c)
 
-/* analogue power on time (100ns) */
+/* analog power on time (100ns) */
 #define	AR9170_PHY_REG_RX_DELAY			(AR9170_PHY_REG_BASE + 0x0114)
 #define	AR9170_PHY_REG_SEARCH_START_DELAY	(AR9170_PHY_REG_BASE + 0x0118)
 #define		AR9170_PHY_RX_DELAY_DELAY		0x00003fff
diff --git a/carl9170fw/tools/carlu/src/fw.c b/carl9170fw/tools/carlu/src/fw.c
index fa4b3881..c8185fca 100644
--- a/carl9170fw/tools/carlu/src/fw.c
+++ b/carl9170fw/tools/carlu/src/fw.c
@@ -58,7 +58,7 @@ int carlu_fw_check(struct carlu *ar)
 	}
 
 	if (carl9170fw_supports(otus_desc->feature_set, CARL9170FW_UNUSABLE))
-		dbg("Firmware is marked as unuseable.\n");
+		dbg("Firmware is marked as unusable.\n");
 
 	info("Firmware Version: %d.\n", otus_desc->api_ver);
 
diff --git a/carl9170fw/tools/carlu/src/test.c b/carl9170fw/tools/carlu/src/test.c
index bf49559f..8d719b61 100644
--- a/carl9170fw/tools/carlu/src/test.c
+++ b/carl9170fw/tools/carlu/src/test.c
@@ -42,7 +42,7 @@
 void debug_test(void)
 {
 	err("This is an error.\n");
-	warn("This is a warnig.\n");
+	warn("This is a warning.\n");
 	info("This is an informative message.\n");
 	dbg("This is just utter useless babble.\n");
 }
@@ -61,7 +61,7 @@ void carlu_frame_test(struct carlu *ar)
 
 	print_hex_dump_bytes(INFO, "DATA:", frame->data, frame->len);
 
-	print_hex_dump_bytes(INFO, "PAYLOAD:", frame->payload, frame->alloced);
+	print_hex_dump_bytes(INFO, "PAYLOAD:", frame->payload, frame->allocated);
 
 	frame_free(frame);
 }
diff --git a/carl9170fw/tools/carlu/src/usb.c b/carl9170fw/tools/carlu/src/usb.c
index ebc19a92..5314cf31 100644
--- a/carl9170fw/tools/carlu/src/usb.c
+++ b/carl9170fw/tools/carlu/src/usb.c
@@ -53,7 +53,7 @@ static const struct {
 	ADD_DEV(0x0cf3, 0x9170, "Atheros", "9170"),
 	ADD_DEV(0x0cf3, 0x1001, "Atheros", "TG121N"),
 	ADD_DEV(0x0cf3, 0x1002, "TP-Link", "TL-WN821N v2"),
-	ADD_DEV(0xcace, 0x0300, "Cace", "Airpcap NX"),
+	ADD_DEV(0xcace, 0x0300, "Cache", "Airpcap NX"),
 	ADD_DEV(0x07d1, 0x3c10, "D-Link", "DWA 160 A1"),
 	ADD_DEV(0x07d1, 0x3a09, "D-Link", "DWA 160 A2"),
 	ADD_DEV(0x0846, 0x9010, "Netgear", "WNDA3100"),
@@ -188,7 +188,7 @@ static int carlusb_get_dev(struct carlu *ar, bool reset)
 		case 0:
 			break;
 		default:
-			err("failed to aquire exculusive access (%d).\n", err);
+			err("failed to acquire exculusive access (%d).\n", err);
 			goto skip;
 		}
 
@@ -518,7 +518,7 @@ static int carlusb_initialize_rxrings(struct carlu *ar)
 
 		err = libusb_submit_transfer(ar->rx_ring[i]);
 		if (err != 0) {
-			err("==>failed to submit rx buld urb (%d)\n", err);
+			err("==>failed to submit rx build urb (%d)\n", err);
 			return EXIT_FAILURE;
 		}
 	}
diff --git a/carl9170fw/tools/include/frame.h b/carl9170fw/tools/include/frame.h
index f753fe31..cccdc5be 100644
--- a/carl9170fw/tools/include/frame.h
+++ b/carl9170fw/tools/include/frame.h
@@ -46,7 +46,7 @@ struct frame_queue {
  * @dcb: more reserved space for low-level / backend driver
  * @queue: selected frame queue / priority
  * @ref: reference counter
  * @alloced: maximum available space
  * @total_len: currently consumed and reserved memory
  * @len: current frame length
  * @head: points to the buffer head
@@ -67,7 +67,7 @@ struct frame {
 
 	unsigned int queue;
 	unsigned int ref;
-	unsigned int alloced;
+	unsigned int allocated;
 	unsigned int total_len;
 	unsigned int len;
 	uint8_t *head;
@@ -91,7 +91,7 @@ static inline void *frame_put(struct frame *frame, unsigned int size)
 {
 	void *tmp;
 
-	BUG_ON(frame->total_len + size > frame->alloced);
+	BUG_ON(frame->total_len + size > frame->allocated);
 
 	frame->len += size;
 	frame->total_len += size;
@@ -99,7 +99,7 @@ static inline void *frame_put(struct frame *frame, unsigned int size)
 	tmp = (void *) frame->tail;
 	frame->tail += size;
 
-	BUG_ON(frame->tail > (frame->payload + frame->alloced));
+	BUG_ON(frame->tail > (frame->payload + frame->allocated));
 
 	return tmp;
 }
@@ -166,7 +166,7 @@ static inline void *frame_pull(struct frame *frame, unsigned int size)
  */
 static inline void frame_reserve(struct frame *frame, unsigned int size)
 {
-	BUG_ON(frame->total_len + size > frame->alloced);
+	BUG_ON(frame->total_len + size > frame->allocated);
 	BUG_ON(frame->len != 0);
 
 	frame->total_len += size;
@@ -210,7 +210,7 @@ static inline struct frame *frame_alloc(unsigned int size)
 		init_list_head(&tmp->dcb.list);
 		tmp->len = 0;
 		tmp->total_len = 0;
-		tmp->alloced = size;
+		tmp->allocated = size;
 
 		tmp->head = tmp->payload;
 		tmp->data = tmp->payload;
@@ -46,7 +46,7 @@ struct frame_queue {
  * @queue: selected frame queue / priority
  * @ref: reference counter
- * @alloced: maximum available space
+ * @allocated: maximum available space
  * @total_len: currently consumed and reserved memory
  * @len: current frame length
-- 
2.25.1


  parent reply	other threads:[~2023-08-15 18:00 UTC|newest]

Thread overview: 24+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2023-08-15 17:59 [PATCH 00/20] Add preparations to be able to run in a CI/CD system Mario Limonciello
2023-08-15 17:59 ` [PATCH 01/20] ath11k: update typographical errors in the Notice.txt files Mario Limonciello
2023-08-15 18:00 ` [PATCH 02/20] ath10k: correct " Mario Limonciello
2023-08-15 18:00 ` [PATCH 03/20] i915: correct typographical errors caught by codespell Mario Limonciello
2023-08-15 18:00 ` [PATCH 04/20] adsp_sst: " Mario Limonciello
2023-08-15 18:00 ` [PATCH 05/20] agere: correct typographical errors in LICENSE " Mario Limonciello
2023-08-15 18:00 ` [PATCH 06/20] qca: correct typographical errors in NOTICE.txt " Mario Limonciello
2023-08-15 18:00 ` [PATCH 07/20] usbdux: correct typographical errors " Mario Limonciello
2023-08-15 18:00 ` [PATCH 08/20] dsp56k: correct typographical error " Mario Limonciello
2023-08-15 18:00 ` [PATCH 09/20] cxgb4: correct typographical errors " Mario Limonciello
2023-08-15 18:00 ` [PATCH 10/20] cavium_liquidio: fix " Mario Limonciello
2023-08-15 18:00 ` [PATCH 11/20] kaweth: correct " Mario Limonciello
2023-08-15 18:00 ` [PATCH 12/20] xc5000c: " Mario Limonciello
2023-08-15 18:00 ` [PATCH 13/20] qcom: " Mario Limonciello
2023-08-15 18:00 ` [PATCH 14/20] keyspan_pda: " Mario Limonciello
2023-08-15 18:00 ` Mario Limonciello [this message]
2023-08-15 18:00 ` [PATCH 16/20] WHENCE: " Mario Limonciello
2023-08-15 18:00 ` [PATCH 17/20] check_whence: reformat using python black Mario Limonciello
2023-08-15 18:00 ` [PATCH 18/20] Add CI/CD with ci-fairy Mario Limonciello
2023-08-15 18:00 ` [PATCH 19/20] Wire up pre-commit to `make check` Mario Limonciello
2023-08-15 18:00 ` [PATCH 20/20] Rewrite README in markdown Mario Limonciello
2023-08-25 17:22 ` [PATCH 00/20] Add preparations to be able to run in a CI/CD system Dmitry Baryshkov
2023-08-28 11:15   ` Josh Boyer
2023-08-30 15:51     ` Mario Limonciello

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20230815180018.25554-16-mario.limonciello@amd.com \
    --to=mario.limonciello@amd.com \
    --cc=jwboyer@kernel.org \
    --cc=linux-firmware@kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).